@@ -30,6 +30,16 @@ impl AWSMachineTemplate {
         self.spec.template.spec.public_ip = Some(yes);
         self
     }
+
+    pub fn namespace(self, namespace: &str) -> Self {
+        Self {
+            metadata: kube::core::ObjectMeta {
+                namespace: Some(namespace.to_string()),
+                ..self.metadata
+            },
+            ..self
+        }
+    }
 }
 
 impl AWSMachineTemplateSpec {
